@@ -175,6 +175,9 @@ LockStruct  LockProcs[] =
 	{"drift",
 	 10000, 30, 1, 1, 64, 1.0, "",
 	 "Shows cosmic drifting flame fractals", 0, NULL, NULL},
+	{"epicycle",
+	 20000, -10, 50000, 1, 64, 1.0, "",
+	 "Shows points moving around a circles recursively", 0, NULL, NULL},
 	{"euler2d",
 	 1000, 1024, 3000, 1, 64, 1.0, "",
 	 "Shows a simulation of 2D incompressible inviscid fluid", 0, NULL, NULL},
@@ -212,7 +215,7 @@ LockStruct  LockProcs[] =
 	 "Shows crashing spiral galaxies", 0, NULL, NULL},
 #ifdef USE_GL
 	{"gears",
-	 50000, 1, 2, 1, 64, 1.0, "",
+	 30000, 0, 2, 0, 64, 1.0, "",
 	 "Shows GL's gears", 0, NULL, "#ifdef USE_GL"},
 	{"glplanet",
 	 15000, 1, 2, 1, 64, 1.0, "",
