@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* bug --- Michael Palmiter's simulated evolution */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)bug.c	5.24 2007/01/18 xlockmore";
 
 #endif
@@ -37,21 +37,21 @@ static const char sccsid[] = "@(#)bug.c	5.24 2007/01/18 xlockmore";
  */
 
 #ifdef STANDALONE
-#define MODE_bug
-#define PROGCLASS "Bug"
-#define HACK_INIT init_bug
-#define HACK_DRAW draw_bug
-#define bug_opts xlockmore_opts
-#define DEFAULTS "*delay: 75000 \n" \
- "*count: 10 \n" \
- "*cycles: 32767 \n" \
- "*size: -4 \n" \
- "*ncolors: 64 \n"
-#include "xlockmore.h"		/* in xscreensaver distribution */
-#else /* STANDALONE */
-#include "xlock.h"		/* in xlockmore distribution */
+# define MODE_bug
+# define DEFAULTS	"*delay: 75000 \n" \
+			"*count: 10 \n" \
+			"*cycles: 32767 \n" \
+			"*size: -4 \n" \
+		 	"*ncolors: 64 \n" \
 
+# define free_bug 0
+# define reshape_bug 0
+# define bug_handle_event 0
+# include "xlockmore.h"		/* in xscreensaver distribution */
+#else /* STANDALONE */
+# include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
+#define DO_STIPPLE
 #include "automata.h"
 
 #ifdef MODE_bug
@@ -85,7 +85,7 @@ static OptionStruct desc[] =
 	{(char *) "-/+vertical", (char *) "change orientation for hexagons and triangles"}
 };
 
-ModeSpecOpt bug_opts =
+ENTRYPOINT ModeSpecOpt bug_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 
@@ -105,7 +105,7 @@ ModStruct   bug_description =
 #define BUGBITS(n,w,h)\
   if ((bp->pixmaps[bp->init_bits]=\
   XCreatePixmapFromBitmapData(display,window,(char *)n,w,h,1,0,1))==None){\
-  free_bug(display,bp); return;} else {bp->init_bits++;}
+  free_bug_screen(display,bp); return;} else {bp->init_bits++;}
 
 #define BACTERIA 0
 #define BUG 1
@@ -135,13 +135,13 @@ typedef struct {
 	int         col, row;
 	int         gene[MAXNEIGHBORS];
 	double      gene_prob[MAXNEIGHBORS];
-#if EXTRA_GENES
+#ifdef EXTRA_GENES
 	int         lgene[MAXNEIGHBORS];
 	double      lgene_prob[MAXNEIGHBORS];
 #endif
 } bugstruct;
 
-/* Doublely linked list */
+/* Doubly linked list */
 typedef struct _BugList {
 	bugstruct   info;
 	struct _BugList *previous, *next;
@@ -191,7 +191,7 @@ positionOfNeighbor(bugfarmstruct * bp, int dir, int *pcol, int *prow)
 {
 	int         col = *pcol, row = *prow;
 
-	/* NO WRAPING */
+	/* NO WRAPPING */
 
 	if (bp->neighbors == 4 || bp->neighbors == 6 || bp->neighbors == 8) {
 		switch (dir) {
@@ -1026,7 +1026,7 @@ mutatebug(bugstruct * info, int local_neighbors)
 		sum += genexp[info->gene[gene] + MAXGENE];
 	for (gene = 0; gene < local_neighbors; gene++)
 		info->gene_prob[gene] = genexp[info->gene[gene] + MAXGENE] / sum;
-#if EXTRA_GENES
+#ifdef EXTRA_GENES
 	if (local_neighbors % 2) {
 		sum = 0.0;
 		gene = NRAND(local_neighbors);
@@ -1090,10 +1090,13 @@ redrawbacteria(ModeInfo * mi, int colrow)
 }
 
 static void
-free_bug(Display *display, bugfarmstruct *bp)
+free_bug_screen(Display *display, bugfarmstruct *bp)
 {
 	int         shade;
 
+	if (bp == NULL) {
+		return;
+	}
 	if (bp->stippledGC != None) {
 		XFreeGC(display, bp->stippledGC);
 		bp->stippledGC = None;
@@ -1130,9 +1133,10 @@ free_bug(Display *display, bugfarmstruct *bp)
 		free(bp->bacteria);
 		bp->bacteria = (char *) NULL;
 	}
+	bp = NULL;
 }
 
-void
+ENTRYPOINT void
 init_bug(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
@@ -1145,11 +1149,7 @@ init_bug(ModeInfo * mi)
 	bugstruct   info;
 	bugfarmstruct *bp;
 
-	if (bugfarms == NULL) {
-		if ((bugfarms = (bugfarmstruct *) calloc(MI_NUM_SCREENS(mi),
-					    sizeof (bugfarmstruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, bugfarms);
 	bp = &bugfarms[MI_SCREEN(mi)];
 
 	if (MI_IS_FULLRANDOM(mi)) {
@@ -1166,7 +1166,7 @@ init_bug(ModeInfo * mi)
 			gcv.fill_style = FillOpaqueStippled;
 			if ((bp->stippledGC = XCreateGC(display, window,
 					GCFillStyle, &gcv)) == None) {
-				free_bug(display, bp);
+				free_bug_screen(display, bp);
 				return;
 			}
 		}
@@ -1181,7 +1181,7 @@ init_bug(ModeInfo * mi)
 		/* Set up what will be a 'triply' linked list.
 		   doubly linked list, doubly linked to an array */
 		if (!init_buglist(bp)) {
-			free_bug(display, bp);
+			free_bug_screen(display, bp);
 			return;
 		}
 		genexp[MAXGENE] = 1;
@@ -1250,14 +1250,14 @@ init_bug(ModeInfo * mi)
 		free(bp->arr);
 	if ((bp->arr = (BugList **) calloc(bp->ncols * bp->nrows,
 			sizeof (BugList *))) == NULL) {
-		free_bug(display, bp);
+		free_bug_screen(display, bp);
 		return;
 	}
 	if (bp->bacteria != NULL)
 		free(bp->bacteria);
 	if ((bp->bacteria = (char *) calloc(bp->ncols * bp->nrows,
 			sizeof (char))) == NULL) {
-		free_bug(display, bp);
+		free_bug_screen(display, bp);
 		return;
 	}
 	bp->edenheight = bp->nrows / 4;
@@ -1334,7 +1334,7 @@ init_bug(ModeInfo * mi)
 				sum += genexp[info.gene[gene] + MAXGENE];
 			for (gene = 0; gene < bp->neighbors; gene++)
 				info.gene_prob[gene] = genexp[info.gene[gene] + MAXGENE] / sum;
-#if EXTRA_GENES
+#ifdef EXTRA_GENES
 			if (bp->neighbors % 2) {
 				for (gene = 0; gene < bp->neighbors; gene++) {
 #if 1
@@ -1366,7 +1366,7 @@ init_bug(ModeInfo * mi)
 			info.row = row;
 			addto_buglist(bp, info);
 			if (bp->firstbug == NULL) {
-				free_bug(display, bp);
+				free_bug_screen(display, bp);
 				return;
 			}
 			bp->arr[colrow] = bp->currbug;
@@ -1383,7 +1383,7 @@ init_bug(ModeInfo * mi)
 }
 
 #define ENOUGH 16
-void
+ENTRYPOINT void
 draw_bug(ModeInfo * mi)
 {
 	int         col, row, ncol = -1, nrow = -1, colrow, ncolrow;
@@ -1460,7 +1460,7 @@ draw_bug(ModeInfo * mi)
 					bp->babybug->info.energy = INITENERGY;
 					dupin_buglist(bp);
 					if (bp->firstbug == NULL) {
-						free_bug(MI_DISPLAY(mi), bp);
+						free_bug_screen(MI_DISPLAY(mi), bp);
 						return;
 					}
 					mutatebug(&bp->babybug->previous->info, bp->neighbors);
@@ -1501,20 +1501,21 @@ draw_bug(ModeInfo * mi)
 	}
 }
 
-void
+ENTRYPOINT void
 release_bug(ModeInfo * mi)
 {
 	if (bugfarms != NULL) {
 		int         screen;
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_bug(MI_DISPLAY(mi), &bugfarms[screen]);
+			free_bug_screen(MI_DISPLAY(mi), &bugfarms[screen]);
 		free(bugfarms);
 		bugfarms = (bugfarmstruct *) NULL;
 	}
 }
 
-void
+#ifndef STANDALONE
+ENTRYPOINT void
 refresh_bug(ModeInfo * mi)
 {
 	bugfarmstruct *bp;
@@ -1530,5 +1531,8 @@ refresh_bug(ModeInfo * mi)
 		bp->redrawpos = 0;
 	}
 }
+#endif
+
+XSCREENSAVER_MODULE ("Bug", bug)
 
 #endif /* MODE_bug */
