@@ -1,11 +1,11 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* molecule --- 3D molecules */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)molecule.c	5.01 2001/04/12 xlockmore";
 #endif
 
-/* molecule, Copyright (c) 2001 Jamie Zawinski <jwz@jwz.org>
+/* molecule, Copyright (c) 2001 Jamie Zawinski <jwz AT jwz.org>
  * Draws molecules, based on coordinates from PDB (Protein Data Base) files.
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
@@ -18,9 +18,9 @@ static const char sccsid[] = "@(#)molecule.c	5.01 2001/04/12 xlockmore";
  *
  *
  * Revision History:
- * 16-May-01:  tschmidt@micron.com
+ * 16-May-01:  tschmidt AT micron.com
  *                              Fix remaining memory leaks. Fix occasional SEGV.
- * 19-Apr-01:  tschmidt@micron.com
+ * 19-Apr-01:  tschmidt AT micron.com
  *                              Fixed most memory leaks
  * 19-Apr-01:  rolf@groppe.de   fixed some allocation problems
  *                              Startup message now only at first call
@@ -46,8 +46,7 @@ static const char sccsid[] = "@(#)molecule.c	5.01 2001/04/12 xlockmore";
  */
 
 #ifdef VMS
-#include "vms_x_fix.h"
-#include <X11/Intrinsic.h>
+#include <types.h>
 #endif
 
 #define DEF_TIMEOUT     "20"
@@ -62,33 +61,21 @@ static const char sccsid[] = "@(#)molecule.c	5.01 2001/04/12 xlockmore";
 
 
 #ifdef STANDALONE
-#define MODE_molecule
-#define PROGCLASS	"Molecule"
-#define HACK_INIT	init_molecule
-#define HACK_DRAW	draw_molecule
-#define HACK_RESHAPE	reshape_molecule
-#define molecule_opts	xlockmore_opts
-
-#define DEFAULTS	"*delay:	10000         \n" \
-			"*timeout:    " DEF_TIMEOUT  "\n" \
+# define MODE_molecule
+# define DEFAULTS	"*delay:	10000         \n" \
 			"*showFPS:      False         \n" \
 			"*wireframe:    False         \n" \
-			"*molecule:   " DEF_MOLECULE "\n" \
-			"*spin:       " DEF_SPIN     "\n" \
-			"*wander:     " DEF_WANDER   "\n" \
-			"*labels:     " DEF_LABELS   "\n" \
-			"*atoms:      " DEF_ATOMS    "\n" \
-			"*bonds:      " DEF_BONDS    "\n" \
-			"*bbox:       " DEF_BBOX     "\n" \
 			"*atomFont:   -*-times-bold-r-normal-*-240-*\n" \
 			"*titleFont:  -*-times-bold-r-normal-*-180-*\n" \
 			"*noLabelThreshold:    30     \n" \
 			"*wireframeThreshold:  150    \n" \
 
-#include "xlockmore.h"
-#include "colors.h"
+# define free_molecule 0
+# define molecule_handle_event 0
+# include "xlockmore.h"
+# include "colors.h"
 #else  /* !STANDALONE */
-# include "xlock.h"					/* from the xlockmore distribution */
+# include "xlock.h"				/* from the xlockmore distribution */
 # include "visgl.h"
 #endif /* !STANDALONE */
 #include "sphere.h"
@@ -268,7 +255,8 @@ static OptionStruct desc[] = {
   {(char *) "-/+bbox", (char *) "turn on/off bbox"},
 };
 
-ModeSpecOpt molecule_opts = {countof(opts), opts, countof(vars), vars, desc};
+ENTRYPOINT ModeSpecOpt molecule_opts =
+{countof(opts), opts, countof(vars), vars, desc};
 
 #ifdef USE_MODULES
 ModStruct   molecule_description =
@@ -301,7 +289,7 @@ static Bool
 load_font (ModeInfo *mi, char *res, XFontStruct **fontP, GLuint *dlistP)
 {
 #ifdef STANDALONE
-  const char *font = get_string_resource (res, "Font");
+  const char *font = get_string_resource (MI_DISPLAY(mi), res, "Font");
 #else
   const char *font = res;
 #endif
@@ -320,16 +308,14 @@ load_font (ModeInfo *mi, char *res, XFontStruct **fontP, GLuint *dlistP)
 
   clear_gl_error ();
   *dlistP = glGenLists ((GLuint) last+1);
-  if (check_gl_error ("glGenLists"))
-	return False;
+  check_gl_error ("glGenLists");
   /*-
    * PURIFY reports a cumulative memory leak on the next line with Mesa 3.4.1
    * on Solaris 2.X and SunOS 4.1.X. This can be fixed with a patch to Mesa
    * 3.4.1. OpenGL on Solaris does not have the memory leak.
    */
   glXUseXFont(id, first, last-first+1, *dlistP + first);
-  if (check_gl_error ("glXUseXFont"))
-	return False;
+  check_gl_error ("glXUseXFont");
 
   *fontP = f;
   return True;
@@ -918,9 +904,10 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
           char *n2 = name;
           int L = strlen(s);
 
-          if (L > 99) L = 99;
-
-          (void) strncpy(n2, s, L);
+          if (L > 99)
+          	(void) strncpy(n2, s, 99);
+          else
+          	(void) strcpy(n2, s);
           n2 += 7;
           while (isspace((int) *n2)) n2++;
 
@@ -1228,7 +1215,7 @@ load_molecules (ModeInfo *mi)
 
 /* Window management, etc
  */
-void
+static void
 reshape_molecule (ModeInfo *mi, int width, int height)
 {
   GLfloat h = (GLfloat) height / (GLfloat) width;
@@ -1251,7 +1238,7 @@ reshape_molecule (ModeInfo *mi, int width, int height)
 
 
 static void
-gl_init()
+gl_init(void)
 {
   static GLfloat pos[4] = {5.0, 5.0, 10.0, 1.0};
   glLightfv(GL_LIGHT0, GL_POSITION, pos);
@@ -1268,7 +1255,9 @@ gl_init()
 
 /* lifted from lament.c */
 #define RAND(n) ((long) ((LRAND() & 0x7fffffff) % ((long) (n))))
+#ifndef RANDSIGN
 #define RANDSIGN() ((LRAND() & 1) ? 1 : -1)
+#endif
 
 static void
 rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v, Bool verbose)
@@ -1356,7 +1345,58 @@ startup_blurb (ModeInfo *mi)
   firstcall = False;
 }
 
-void
+ENTRYPOINT void
+release_molecule(ModeInfo * mi)
+{
+  if (mcs != NULL) {
+	int         screen;
+
+	for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
+	  molecule_configuration *mc = &mcs[screen];
+
+#if 0
+	int         i;
+
+	  for (i = 0; i < mc->nmolecules; i++) {
+	    molecule *m = &mc->molecules[i];
+
+	    if (m->atoms) {
+		free(m->atoms);
+		m->atoms = (molecule_atom *) NULL;
+	    }
+	    if (m->bonds) {
+		free(m->bonds);
+		m->bonds = (molecule_bond *) NULL;
+	    }
+	    if (m->label) {
+		free(m->label);
+		m->label = (char *) NULL;
+	    }
+	  }
+	  if (mc->molecules) {
+		free(mc->molecules);
+		mc->molecules = (molecule *) NULL;
+	  }
+#endif
+
+	  if (mc->glx_context) {
+		/* Display lists MUST be freed while their glXContext is current. */
+#ifdef WIN32
+		wglMakeCurrent(hdc, mc->glx_context);
+#else
+		glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(mc->glx_context));
+#endif
+		/* Free font stuff */
+		free_fonts (mi);
+	  }
+	}
+	free(mcs);
+	mcs = (molecule_configuration *) NULL;
+  }
+  FreeAllGL(mi);
+}
+
+ENTRYPOINT void
 init_molecule (ModeInfo *mi)
 {
   molecule_configuration *mc;
@@ -1365,14 +1405,7 @@ init_molecule (ModeInfo *mi)
 #ifndef STANDALONE
   timeout = MI_CYCLES(mi);
 #endif
-  if (!mcs) {
-    mcs = (molecule_configuration *)
-      calloc (MI_NUM_SCREENS(mi), sizeof (molecule_configuration));
-    if (!mcs) {
-       return;
-    }
-  }
-
+  MI_INIT(mi, mcs);
   mc = &mcs[MI_SCREEN(mi)];
   if (mc->glx_context) {
 	/* Free font stuff */
@@ -1434,9 +1467,11 @@ init_molecule (ModeInfo *mi)
   mc->which =  NRAND(mc->nmolecules);
 
 #ifdef STANDALONE
-  mc->no_label_threshold = get_float_resource ("noLabelThreshold",
+  mc->no_label_threshold = get_float_resource (MI_DISPLAY(mi),
+                                               "noLabelThreshold",
                                                "NoLabelThreshold");
-  mc->wireframe_threshold = get_float_resource ("wireframeThreshold",
+  mc->wireframe_threshold = get_float_resource (MI_DISPLAY(mi),
+                                                "wireframeThreshold",
                                                 "WireframeThreshold");
 #else
   mc->no_label_threshold = 30;
@@ -1448,7 +1483,7 @@ init_molecule (ModeInfo *mi)
 }
 
 
-void
+ENTRYPOINT void
 draw_molecule (ModeInfo *mi)
 {
 /*  static time_t last = 0; */
@@ -1565,55 +1600,6 @@ draw_molecule (ModeInfo *mi)
   glXSwapBuffers(dpy, window);
 }
 
-void
-release_molecule(ModeInfo * mi)
-{
-  if (mcs != NULL) {
-	int         screen;
+XSCREENSAVER_MODULE ("Molecule", molecule)
 
-	for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
-	  molecule_configuration *mc = &mcs[screen];
-
-#if 0
-	int         i;
-
-	  for (i = 0; i < mc->nmolecules; i++) {
-	    molecule *m = &mc->molecules[i];
-
-	    if (m->atoms) {
-		free(m->atoms);
-		m->atoms = (molecule_atom *) NULL;
-	    }
-	    if (m->bonds) {
-		free(m->bonds);
-		m->bonds = (molecule_bond *) NULL;
-	    }
-	    if (m->label) {
-		free(m->label);
-		m->label = (char *) NULL;
-	    }
-	  }
-	  if (mc->molecules) {
-		free(mc->molecules);
-		mc->molecules = (molecule *) NULL;
-	  }
-#endif
-
-	  if (mc->glx_context) {
-		/* Display lists MUST be freed while their glXContext is current. */
-#ifdef WIN32
-		wglMakeCurrent(hdc, mc->glx_context);
-#else
-		glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(mc->glx_context));
-#endif
-		/* Free font stuff */
-		free_fonts (mi);
-	  }
-	}
-	free(mcs);
-	mcs = (molecule_configuration *) NULL;
-  }
-  FreeAllGL(mi);
-}
-
-#endif /* USE_GL */
+#endif /* MODE_molecule */
