@@ -42,7 +42,8 @@ struct rotator {
 
 #undef ABS
 #define ABS(x) ((x)<0?-(x):(x))
-
+#undef random
+#define random() LRAND()
 #define BELLRAND(n) ((frand((n)) + frand((n)) + frand((n))) / 3)
 #define RANDSIGN() ((random() & 1) ? 1 : -1)
 
