@@ -1,9 +1,8 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* superquadrics --- 3D mathematical shapes */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)superquadrics.c	5.01 2001/03/01 xlockmore";
-
 #endif
 
 /*-
@@ -73,26 +72,17 @@ static const char sccsid[] = "@(#)superquadrics.c	5.01 2001/03/01 xlockmore";
  * Ed Mackey
  */
 
-#ifdef VMS
-/*-
- * due to a Bug/feature in VMS X11/Intrinsic.h has to be placed before xlock.
- * otherwise caddr_t is not defined correctly
- */
-
-#include <X11/Intrinsic.h>
-#endif
-
 #ifdef STANDALONE
 # define MODE_superquadrics
-# define PROGCLASS				"Superquadrics"
-# define HACK_INIT				init_superquadrics
-# define HACK_DRAW				draw_superquadrics
-# define superquadrics_opts			xlockmore_opts
 # define DEFAULTS	"*delay:	40000   \n"	\
 			"*count:	25      \n"	\
 			"*cycles:	40      \n"	\
 			"*showfps:      False   \n"	\
 			"*wireframe:	False	\n"
+
+#define free_superquadrics 0
+#define reshape_superquadrics 0
+#define superquadrics_handle_event 0
 # include "xlockmore.h"			/* from the xscreensaver distribution */
 #else  /* !STANDALONE */
 # include "xlock.h"			/* from the xlockmore distribution */
@@ -125,14 +115,14 @@ static OptionStruct desc[] =
 	{(char *) "-spinspeed num", (char *) "speed of rotation, in degrees per frame"}
 };
 
-ModeSpecOpt superquadrics_opts =
+ENTRYPOINT ModeSpecOpt superquadrics_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
 ModStruct   superquadrics_description =
 {"superquadrics", "init_superquadrics", "draw_superquadrics", "release_superquadrics",
- "refresh_superquadrics", "init_superquadrics", (char *) NULL, &superquadrics_opts,
- 40000, 25, 40, 1, 4, 1.0, "",
+ (char *) NULL, "init_superquadrics", (char *) NULL, &superquadrics_opts,
+ 40000, 25, 40, 1, 64, 1.0, "",
  "Shows 3D mathematical shapes", 0, NULL};
 
 #endif
@@ -406,7 +396,7 @@ DoneScale(superquadricsstruct * sp)
 						glVertex3f(xx, yy, zz);
 						glVertex3f(sp->Prevxx[iv - 1], sp->Prevyy[iv - 1], sp->Prevzz[iv - 1]);
 					}
-/* PURIFY 4.0.1 reports an unitialized memory read on the next line when using
+/* PURIFY 4.0.1 reports an uninitialized memory read on the next line when using
    * MesaGL 2.2 and -mono.  This has been fixed in MesaGL 2.3 and later. */
 					glEnd();
 				}
@@ -718,7 +708,7 @@ InitSuperquadrics(int wfmode, int snorm, int res, int count, float speed, superq
 
 /* End of superquadrics main functions */
 
-void
+ENTRYPOINT void
 init_superquadrics(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
@@ -727,11 +717,7 @@ init_superquadrics(ModeInfo * mi)
 
 	superquadricsstruct *sp;
 
-	if (superquadrics == NULL) {
-		if ((superquadrics = (superquadricsstruct *) calloc(MI_NUM_SCREENS(mi),
-				      sizeof (superquadricsstruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, superquadrics);
 	sp = &superquadrics[screen];
 	sp->mono = (MI_IS_MONO(mi) ? 1 : 0);
 
@@ -749,7 +735,7 @@ init_superquadrics(ModeInfo * mi)
 	}
 }
 
-void
+ENTRYPOINT void
 draw_superquadrics(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
@@ -775,13 +761,7 @@ draw_superquadrics(ModeInfo * mi)
 	glXSwapBuffers(display, window);
 }
 
-void
-refresh_superquadrics(ModeInfo * mi)
-{
-	/* Nothing happens here */
-}
-
-void
+ENTRYPOINT void
 release_superquadrics(ModeInfo * mi)
 {
 	if (superquadrics != NULL) {
@@ -791,7 +771,8 @@ release_superquadrics(ModeInfo * mi)
 	FreeAllGL(mi);
 }
 
+XSCREENSAVER_MODULE ("Superquadrics", superquadrics)
 
-#endif
+#endif /* MODE_superquadrics */
 
 /* End of superquadrics.c */
