@@ -347,7 +347,7 @@ initStrings(ModeInfo * mi)
 	ip->lines = height;
 	j = 0;
 	for (i = 0; i < ip->lines; i++) {
-		if (ip->strnew[i] && *(ip->strnew[i])) {
+		if (*(ip->strnew[i])) {
 			ip->textWidth[i] = getTextWidth(ip->strnew[i]) +
 				getTextWidth((char *) "I");
 			/* add a little more to give some border room */
