@@ -402,6 +402,9 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_pacman
 	"pacman",
 #endif
+#ifdef MODE_paterson
+	"paterson",
+#endif
 #ifdef MODE_penrose
 	"penrose",
 #endif
@@ -432,6 +435,9 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_spiral
 	"spiral",
 #endif
+#ifdef MODE_spirolateral
+	"spirolateral",
+#endif
 #ifdef MODE_spline
 	"spline",
 #endif
@@ -564,9 +570,15 @@ static char automata_modes[][MAXMODECHARS] =
 #ifdef MODE_loop
 	"loop",
 #endif
+#ifdef MODE_paterson
+	"paterson",
+#endif
 #ifdef MODE_petri
 	"petri",
 #endif
+#ifdef MODE_squiral
+	"squiral",
+#endif
 #ifdef MODE_voters
 	"voters",
 #endif
@@ -700,6 +712,9 @@ static char geometry_modes[][MAXMODECHARS] =
 #ifdef MODE_spiral
 	"spiral",
 #endif
+#ifdef MODE_spirolateral
+	"spirolateral",
+#endif
 #ifdef MODE_spline
 	"spline",
 #endif
