@@ -65,7 +65,10 @@ ModStruct   turtle_description =
 #define KOCH_SNOWFLAKE 4
 #define SIERPINSKI 5
 #define SIERPINSKI_ARROWHEAD 6
-#define TURTLE_CURVES 7
+#define H_TREE 7
+#define TURTLE_CURVES 8
+
+/* Lindenmayer system */
 
 /* https://en.wikipedia.org/wiki/Hilbert_curve */
 /* HILBERT */
@@ -494,6 +497,89 @@ generate_sierpinski_arrowhead(ModeInfo * mi, double x, double y,
 	}
 }
 
+static void
+generate_h_tree(ModeInfo * mi, double x, double y,
+		double length, int level)
+{
+	Display    *display = MI_DISPLAY(mi);
+	Window      window = MI_WINDOW(mi);
+	GC          gc = MI_GC(mi);
+	turtlestruct *tp = &turtles[MI_SCREEN(mi)];
+
+	if (level > 0) {
+		tp->turtle.x = x;
+		tp->turtle.y = y;
+
+		STEP(tp->turtle.x, tp->turtle.y, length / 2.0, tp->turtle.theta);
+		XDrawLine(display, window, gc, (int) x, (int) y,
+			(int) tp->turtle.x, (int) tp->turtle.y);
+		x = tp->turtle.x;
+		y = tp->turtle.y;
+		TURN(tp->turtle.theta, -90);
+		STEP(tp->turtle.x, tp->turtle.y, length / 2.0, tp->turtle.theta);
+		XDrawLine(display, window, gc, (int) x, (int) y,
+			(int) tp->turtle.x, (int) tp->turtle.y);
+		x = tp->turtle.x;
+		y = tp->turtle.y;
+		TURN(tp->turtle.theta, 90);
+
+		generate_h_tree(mi, x, y, length  / 2.0, level - 1);
+
+		TURN(tp->turtle.theta, 90);
+		STEP(tp->turtle.x, tp->turtle.y, length, tp->turtle.theta);
+		XDrawLine(display, window, gc, (int) x, (int) y,
+			(int) tp->turtle.x, (int) tp->turtle.y);
+		x = tp->turtle.x;
+		y = tp->turtle.y;
+		TURN(tp->turtle.theta, -90);
+
+		generate_h_tree(mi, x, y, length  / 2.0, level - 1);
+
+		TURN(tp->turtle.theta, -90);
+		STEP(tp->turtle.x, tp->turtle.y, length / 2.0, tp->turtle.theta);
+		XDrawLine(display, window, gc, (int) x, (int) y,
+			(int) tp->turtle.x, (int) tp->turtle.y);
+		x = tp->turtle.x;
+		y = tp->turtle.y;
+		TURN(tp->turtle.theta, -90);
+		STEP(tp->turtle.x, tp->turtle.y, length, tp->turtle.theta);
+		XDrawLine(display, window, gc, (int) x, (int) y,
+			(int) tp->turtle.x, (int) tp->turtle.y);
+		x = tp->turtle.x;
+		y = tp->turtle.y;
+		TURN(tp->turtle.theta, 90);
+		STEP(tp->turtle.x, tp->turtle.y, length / 2.0, tp->turtle.theta);
+		XDrawLine(display, window, gc, (int) x, (int) y,
+			(int) tp->turtle.x, (int) tp->turtle.y);
+		x = tp->turtle.x;
+		y = tp->turtle.y;
+		TURN(tp->turtle.theta, -90);
+
+		generate_h_tree(mi, x, y, length  / 2.0, level - 1);
+
+		TURN(tp->turtle.theta, -90);
+		STEP(tp->turtle.x, tp->turtle.y, length, tp->turtle.theta);
+		XDrawLine(display, window, gc, (int) x, (int) y,
+			(int) tp->turtle.x, (int) tp->turtle.y);
+		x = tp->turtle.x;
+		y = tp->turtle.y;
+		TURN(tp->turtle.theta, -90);
+
+		generate_h_tree(mi, x, y, length  / 2.0, level - 1);
+
+		TURN(tp->turtle.theta, -90);
+		STEP(tp->turtle.x, tp->turtle.y, length / 2.0, tp->turtle.theta);
+		XDrawLine(display, window, gc, (int) x, (int) y,
+			(int) tp->turtle.x, (int) tp->turtle.y);
+		x = tp->turtle.x;
+		y = tp->turtle.y;
+		TURN(tp->turtle.theta, 90);
+		STEP(tp->turtle.x, tp->turtle.y, length / 2.0, tp->turtle.theta);
+		XDrawLine(display, window, gc, (int) x, (int) y,
+			(int) tp->turtle.x, (int) tp->turtle.y);
+	}
+}
+
 ENTRYPOINT void
 init_turtle(ModeInfo * mi)
 {
@@ -631,6 +717,11 @@ init_turtle(ModeInfo * mi)
 		tp->start.x = NRAND(tp->width - tp->min);
 		tp->start.y = NRAND(tp->height - tp->min) / 2 + 3 * tp->height / 4;
 		break;
+	case H_TREE:
+		tp->min = tp->min / 3;
+		tp->start.x = NRAND(tp->width - tp->min) / 2 + tp->width / 4;
+		tp->start.y = NRAND(tp->height - tp->min) / 2 + 3 * tp->height / 8;
+		break;
 	}
 	tp->level = 0;
 	tp->sign = 1;
@@ -723,7 +814,12 @@ draw_turtle(ModeInfo * mi)
 		case SIERPINSKI_ARROWHEAD:
 			TURN(tp->turtle.theta, -60);
 			generate_sierpinski_arrowhead(mi, tp->start.x, tp->start.y,
-					tp->min, 60, tp->level);
+				tp->min, 60, tp->level);
+			break;
+		case H_TREE:
+			TURN(tp->turtle.theta, 0);
+			generate_h_tree(mi, tp->start.x, tp->start.y,
+				tp->min, tp->level);
 			break;
 		}
 	XSetLineAttributes(MI_DISPLAY(mi), MI_GC(mi), 1,
