@@ -234,6 +234,12 @@ LockStruct  LockProcs[] =
 	 10000, 30, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows cosmic drifting flame fractals", 0, NULL},
 #endif
+#ifdef MODE_epicycle
+	{(char *) "epicycle", init_epicycle, draw_epicycle, release_epicycle,
+	 draw_epicycle, init_epicycle, (ModeHook *) NULL, &epicycle_opts,
+	 20000, -10, 50000, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows oints moving around a circles recursively", 0, NULL},
+#endif
 #ifdef MODE_euler2d
 	{(char *) "euler2d", init_euler2d, draw_euler2d, release_euler2d,
 	 refresh_euler2d, init_euler2d, (ModeHook *) NULL, &euler2d_opts,
@@ -303,7 +309,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_gears
 	{(char *) "gears", init_gears, draw_gears, release_gears,
 	 draw_gears, init_gears, (ModeHook *) NULL, &gears_opts,
-	 50000, 1, 2, 1, 64, 1.0, (char *) "",
+	 30000, 0, 2, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows GL's gears", 0, NULL},
 #endif
 #ifdef MODE_glplanet
