@@ -426,6 +426,7 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_discrete
 #define MODE_dragon
 #define MODE_drift
+#define MODE_epicycle
 #define MODE_euler2d
 #define MODE_eyes
 #define MODE_fadeplot
@@ -872,6 +873,13 @@ extern ModeHook refresh_drift;
 extern ModeSpecOpt drift_opts;
 #endif
 
+#ifdef MODE_epicycle
+extern ModeHook init_epicycle;
+extern ModeHook draw_epicycle;
+extern ModeHook release_epicycle;
+extern ModeSpecOpt epicycle_opts;
+#endif
+
 #ifdef MODE_euler2d
 extern ModeHook init_euler2d;
 extern ModeHook draw_euler2d;
