@@ -53,6 +53,7 @@ static LockStruct LockProcs[] =
 {(char *) "discrete", (char *) "Shows various discrete maps"},
 {(char *) "dragon", (char *) "Shows Deventer's Hexagonal Dragons Maze"},
 {(char *) "drift", (char *) "Shows cosmic drifting flame fractals"},
+{(char *) "epicycle", (char *) "Shows points moving around a circles recursively"},
 {(char *) "euler2d", (char *) "Shows a simulation of 2D incompressible inviscid fluid"},
 {(char *) "eyes", (char *) "Shows eyes following a bouncing grelb"},
 {(char *) "fadeplot", (char *) "Shows a fading plot of sine squared"},
@@ -131,6 +132,7 @@ static LockStruct LockProcs[] =
 {(char *) "oct", (char *) "Shows an auto-solving octahedron puzzle"},
 #endif
 {(char *) "pacman", (char *) "Shows Pacman(tm)"},
+{(char *) "paterson", (char *) "Shows Paterson's Worm Paths"},
 {(char *) "penrose", (char *) "Shows Penrose's quasiperiodic tilings"},
 {(char *) "petal", (char *) "Shows various GCD Flowers"},
 {(char *) "petri", (char *) "Shows a mold simulation in a petri dish"},
@@ -170,10 +172,12 @@ static LockStruct LockProcs[] =
 {(char *) "space", (char *) "Shows a journey into deep space"},
 {(char *) "sphere", (char *) "Shows a bunch of shaded spheres"},
 {(char *) "spiral", (char *) "Shows a helical locus of points"},
+{(char *) "spirolateral", (char *) "Shows Odds' Spirolaterals"},
 {(char *) "spline", (char *) "Shows colorful moving splines"},
 #ifdef USE_GL
 {(char *) "sproingies", (char *) "Shows Sproingies!  Nontoxic.  Safe for pets and small children"},
 #endif
+{(char *) "squiral", (char *) "Shows spiral-producing automata"},
 #ifdef USE_GL
 {(char *) "stairs", (char *) "Shows some Infinite Stairs, an Escher-like scene"},
 #endif
